import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.net.Socket;

public class ServerThread extends Thread {

	private static final int UNABLE_TO_OPEN_INPUT_STREAM = -1;
	private static final int UNABLE_TO_OPEN_OUTPUT_STREAM = -2;
	private static final int UNABLE_TO_READ_FROM_BUFFERED_READER = -3;
	private static final int UNABLE_TO_CLOSE_CLIENT_SOCKET = -4;
	
	private InputStream input;
	private BufferedReader reader;
	
	private OutputStream output;
	private PrintWriter writer;
	
	private Socket socket = null;
	
	public ServerThread(Socket socket) {
		this.socket = socket;
	}
	
	@Override
	public void run() {
		super.run();

		try {
			input = socket.getInputStream();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(UNABLE_TO_OPEN_INPUT_STREAM);
		}
		
		this.reader = new BufferedReader(new InputStreamReader(input));
		
		try {
			this.output = socket.getOutputStream();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(UNABLE_TO_OPEN_OUTPUT_STREAM);
		}
		
		this.writer = new PrintWriter(this.output, true);
		
		String message = "";
		
		do {
			try {
				message = this.reader.readLine();
			} catch (IOException e) {
				e.printStackTrace();
				System.exit(UNABLE_TO_READ_FROM_BUFFERED_READER);
			}
			
			System.out.println("Input Message = " + message);
			
			if (!message.equalsIgnoreCase("end")) {
				// change meesage to upper case
				String response = message.toUpperCase() + "\tLength = " + message.length();

				System.out.println("     Response = " + response);				
				
				this.writer.println(response);
			}
		} while (!message.equalsIgnoreCase("end"));
		
		System.out.println("Client Connection Ended");
		
		try {
			this.socket.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(UNABLE_TO_CLOSE_CLIENT_SOCKET);
		}
	}

}
